value

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrEmptyTitle = errors.New("title is empty")

Functions

func IsFenceLine

func IsFenceLine(line string) bool

IsFenceLine reports whether the line is fence line.

Types

type FenceLine

type FenceLine struct {
	// contains filtered or unexported fields
}

FenceLine represents a fence text line.

func NewFenceLine

func NewFenceLine(line string) (*FenceLine, bool)

NewFenceLine returns Fence line.

func (FenceLine) HasShellID

func (fl FenceLine) HasShellID() bool

HasShellID reports whether the fence line has shell identifier.

type Title

type Title struct {
	// contains filtered or unexported fields
}

Title represents a title that does not allow empty titles.

func NewTitle

func NewTitle(t string) (*Title, error)

NewTitleLine returns title.

func (Title) Equals

func (t Title) Equals(other *Title) bool

Equal reports whether the title equals to other title.

func (Title) String

func (t Title) String() string

String returns a title string.

type TitleLine

type TitleLine struct {
	// contains filtered or unexported fields
}

TitleLine represents a title text line that allows empty titles.

func NewTitleLine

func NewTitleLine(tl string) (*TitleLine, bool)

NewTitleLine returns title line.

func (TitleLine) EqualTitle

func (tl TitleLine) EqualTitle(title *Title) bool

EqualTitle reports whether a title equals to a title in the title line.

func (TitleLine) HasValidTitle

func (tl TitleLine) HasValidTitle() bool

HasValidTitle reports whether a title in the title line is valid.

func (TitleLine) Title

func (tl TitleLine) Title() Title

Title returns a title in the title line.

Jump to