Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrEmptyTitle = errors.New("title is empty")
Functions ¶
func IsFenceLine ¶
IsFenceLine reports whether the line is fence line.
Types ¶
type FenceLine ¶
type FenceLine struct {
// contains filtered or unexported fields
}
FenceLine represents a fence text line.
func NewFenceLine ¶
NewFenceLine returns Fence line.
func (FenceLine) HasShellID ¶
HasShellID reports whether the fence line has shell identifier.
type Title ¶
type Title struct {
// contains filtered or unexported fields
}
Title represents a title that does not allow empty titles.
type TitleLine ¶
type TitleLine struct {
// contains filtered or unexported fields
}
TitleLine represents a title text line that allows empty titles.
func NewTitleLine ¶
NewTitleLine returns title line.
func (TitleLine) EqualTitle ¶
EqualTitle reports whether a title equals to a title in the title line.
func (TitleLine) HasValidTitle ¶
HasValidTitle reports whether a title in the title line is valid.
Click to show internal directories.
Click to hide internal directories.